@@ -10,10 +10,11 @@ function(x) x$summary$Weight
 
 `Weights.data.frame` <-
 function(x) {
-	if(ncol(x) == 2L && colnames(x)[2L] %in% c("AIC", "AICc", "BIC", "QAIC", "QAICc")
-	&& is.numeric(x[, 2L]))
-		Weights.default(x[, 2L])
-	else NA
+	if(ncol(x) == 2L && colnames(x)[1L] == "df"	&& is.numeric(x[, 2L]))
+		return(Weights.default(x[, 2L]))
+	if(ncol(x) == 1L && is.numeric(x[, 1L]))
+		return(Weights.default(x[, 1L]))
+	return(NA)
 }
 
 `Weights.default` <-
